@@ -32,9 +32,9 @@
 #include <dirent.h>
 #include <fcntl.h>
 #include <memory.h>
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstring>
+#include <cstdio>
+#include <cstdlib>
 #include <sys/param.h>
 #include <sys/stat.h>
 
@@ -239,7 +239,7 @@ const char *XrdDigDirectory::nextEntry()
 
 // Read the next directory entry
 //
-#ifdef __linux__
+#if defined(__linux__) || defined(__GNU__) || (defined(__FreeBSD_kernel__) && defined(__GLIBC__))
 do{errno = 0;
    rp = readdir(dh);
    if (!rp)
@@ -676,7 +676,7 @@ int XrdDigFS::exists(const char                *path,        // In
        return SFS_OK;
       }
 
-// An error occured, return the error info
+// An error occurred, return the error info
 //
    return XrdDigFS::Emsg(epname, error, errno, "locate", path);
 }
